:tocdepth: 2

.. _authors:

Authors
=======

py7zr is written and maintained by Hiroshi Miura <miurahr@linux.com>

Contributors, listed alphabetically, are:

* Joachim Bauch -- pylzma orginator
* Kazuya Fujioka -- fix zero file problem
